==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGroupByExpandStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescriptionMetadata } from "./WebGroupByKeyDescriptionMetadata";
import { WebGroupByExpandStateDescription } from "./WebGroupByExpandStateDescription";
/**
 * @hidden
 */
export let WebGroupByExpandStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByExpandStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByExpandStateDescriptionMetadata.a == null) {
                WebGroupByExpandStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByExpandStateDescriptionMetadata.c(WebGroupByExpandStateDescriptionMetadata.a);
            }
            if (a.j(WebGroupByExpandStateDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGroupByExpandStateDescriptionMetadata.a);
            WebGroupByKeyDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByExpandState");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Expanded", "Boolean");
            a.item("Hierarchy", "Array:WebGroupByKeyDescription:GroupByKey");
        }
        static d(a) {
            WebGroupByExpandStateDescriptionMetadata.b(a);
            a.aa("WebGroupByExpandState", () => new WebGroupByExpandStateDescription());
            a.z("WebGroupByExpandState", WebGroupByExpandStateDescriptionMetadata.a);
        }
    }
    WebGroupByExpandStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByExpandStateDescriptionMetadata, 'WebGroupByExpandStateDescriptionMetadata');
    WebGroupByExpandStateDescriptionMetadata.a = null;
    return WebGroupByExpandStateDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGroupByExpandStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByKeyDescriptionMetadata } from "./WebGroupByKeyDescriptionMetadata";
import { WebGroupByExpandStateDescription } from "./WebGroupByExpandStateDescription";
/**
 * @hidden
 */
export let WebGroupByExpandStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByExpandStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByExpandStateDescriptionMetadata.a == null) {
                WebGroupByExpandStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByExpandStateDescriptionMetadata.c(WebGroupByExpandStateDescriptionMetadata.a);
            }
            if (a.k(WebGroupByExpandStateDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGroupByExpandStateDescriptionMetadata.a);
            WebGroupByKeyDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByExpandState");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Expanded", "Boolean");
            a.item("Hierarchy", "Array:WebGroupByKeyDescription:GroupByKey");
        }
        static d(a) {
            WebGroupByExpandStateDescriptionMetadata.b(a);
            a.ac("WebGroupByExpandState", () => new WebGroupByExpandStateDescription());
            a.ab("WebGroupByExpandState", WebGroupByExpandStateDescriptionMetadata.a);
        }
    }
    WebGroupByExpandStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByExpandStateDescriptionMetadata, 'WebGroupByExpandStateDescriptionMetadata');
    WebGroupByExpandStateDescriptionMetadata.a = null;
    return WebGroupByExpandStateDescriptionMetadata;
})();
